@@ -81,6 +81,7 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  dmatrixType="auto",
                  backend="auto",
                  gpuId=0,
+                 interactionConstraints=None,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -101,7 +102,8 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OXGBoost, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OXGBoostClassifier", self.uid)
