@@ -82,7 +82,6 @@ class H2OGLMRegressor(H2OGLM):
                  maxConfusionMatrixSize=20,
                  computePValues=False,
                  removeCollinearCols=False,
-                 generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -109,7 +108,6 @@ class H2OGLMRegressor(H2OGLM):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2OGLMRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
         if 'distribution' in kwargs:
             del kwargs['distribution']
             warn("The parameter 'distribution' is deprecated and will be removed in the version 3.34.")
