@@ -272,6 +272,11 @@ class H2OGLMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
         return value
 
 
+    def getCheckpoint(self):
+        value = self._java_obj.getCheckpoint()
+        return value
+
+
     def getStoppingRounds(self):
         value = self._java_obj.getStoppingRounds()
         return value
