@@ -18,8 +18,18 @@
 from ai.h2o.sparkling.ml.models.H2OTargetEncoderModel import H2OTargetEncoderModel
 from ai.h2o.sparkling.ml.models.H2OTargetEncoderMOJOModel import H2OTargetEncoderMOJOModel
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
-from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OMOJOModel
-from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OSupervisedMOJOModel
-from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OTreeBasedSupervisedMOJOModel
-from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OUnsupervisedMOJOModel
+from ai.h2o.sparkling.ml.models.H2OXGBoostMOJOModel import H2OXGBoostMOJOModel
+from ai.h2o.sparkling.ml.models.H2OGBMMOJOModel import H2OGBMMOJOModel
+from ai.h2o.sparkling.ml.models.H2ODRFMOJOModel import H2ODRFMOJOModel
+from ai.h2o.sparkling.ml.models.H2OGLMMOJOModel import H2OGLMMOJOModel
+from ai.h2o.sparkling.ml.models.H2OGAMMOJOModel import H2OGAMMOJOModel
+from ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel import H2ODeepLearningMOJOModel
+from ai.h2o.sparkling.ml.models.H2OKMeansMOJOModel import H2OKMeansMOJOModel
+from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationForestMOJOModel
 from ai.h2o.sparkling.ml.models.H2OMOJOPipelineModel import H2OMOJOPipelineModel
+from ai.h2o.sparkling.ml.models.H2OBinaryModel import H2OBinaryModel
+from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OTreeBasedSupervisedMOJOModel
+from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OTreeBasedUnsupervisedMOJOModel
+from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OSupervisedMOJOModel
+from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OUnsupervisedMOJOModel
+from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OMOJOModel
