@@ -330,6 +330,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Whether to score during each iteration of model training.""",
         H2OTypeConverters.toBoolean())
 
+    checkpoint = Param(
+        Params._dummy(),
+        "checkpoint",
+        """Model checkpoint to resume training with.""",
+        H2OTypeConverters.toNullableString())
+
     stoppingRounds = Param(
         Params._dummy(),
         "stoppingRounds",
@@ -366,6 +372,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -519,6 +531,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getScoreEachIteration(self):
         return self.getOrDefault(self.scoreEachIteration)
 
+    def getCheckpoint(self):
+        return self.getOrDefault(self.checkpoint)
+
     def getStoppingRounds(self):
         return self.getOrDefault(self.stoppingRounds)
 
@@ -537,6 +552,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -690,6 +708,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setScoreEachIteration(self, value):
         return self._set(scoreEachIteration=value)
 
+    def setCheckpoint(self, value):
+        return self._set(checkpoint=value)
+
     def setStoppingRounds(self, value):
         return self._set(stoppingRounds=value)
 
@@ -707,3 +728,6 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
